summaryrefslogtreecommitdiff
path: root/indra/newview/llsnapshotlivepreview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llsnapshotlivepreview.cpp')
-rw-r--r--indra/newview/llsnapshotlivepreview.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/indra/newview/llsnapshotlivepreview.cpp b/indra/newview/llsnapshotlivepreview.cpp
index c6f8c414fa..ee8b2d79c0 100644
--- a/indra/newview/llsnapshotlivepreview.cpp
+++ b/indra/newview/llsnapshotlivepreview.cpp
@@ -1080,12 +1080,13 @@ BOOL LLSnapshotLivePreview::saveLocal()
return success;
}
//Check if failed due to insuficient memory
BOOL LLSnapshotLivePreview::saveLocal(LLPointer<LLImageFormatted> mFormattedImage)
{
- BOOL success = gViewerWindow->saveImageNumbered(mFormattedImage);
+ BOOL insufficient_memory;
+ BOOL success = gViewerWindow->saveImageNumbered(mFormattedImage, FALSE, insufficient_memory);
- if (!success)
+ if (insufficient_memory)
{
std::string lastSnapshotDir = LLViewerWindow::getLastSnapshotDir();
@@ -1080,12 +1080,13 @@ BOOL LLSnapshotLivePreview::saveLocal()
return success;
}
-//Check if failed due to insuficient memory
+//Check if failed due to insufficient memory
BOOL LLSnapshotLivePreview::saveLocal(LLPointer<LLImageFormatted> mFormattedImage)
{